@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,11 +19,11 @@ void SievePreviewGeneratedCodeWidgetTest::shouldHaveDefaultValues()
 {
     KSieveUi::SievePreviewGeneratedCodeWidget w;
 
-    auto *mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 
-    auto *mTextEdit = w.findChild<QTextEdit *>(QStringLiteral("mTextEdit"));
+    auto mTextEdit = w.findChild<QTextEdit *>(QStringLiteral("mTextEdit"));
     QVERIFY(mTextEdit);
     QVERIFY(mTextEdit->isReadOnly());
 }
