@@ -1,20 +1,20 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionfileinto.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
+#include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include "editor/sieveeditorutil.h"
 #include "widgets/moveimapfolderwidget.h"
-#include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include <KLocalizedString>
 
+#include "libksieve_debug.h"
 #include <QCheckBox>
 #include <QHBoxLayout>
-#include "libksieve_debug.h"
 #include <QXmlStreamReader>
-//Add support for adding flags
+// Add support for adding flags
 using namespace KSieveUi;
 SieveActionFileInto::SieveActionFileInto(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
     : SieveAction(sieveGraphicalModeWidget, QStringLiteral("fileinto"), i18n("File Into"), parent)
@@ -51,7 +51,7 @@ void SieveActionFileInto::setParamWidgetValue(QXmlStreamReader &element, QWidget
             const QString tagValue = element.readElementText();
             if (tagValue == QLatin1String("copy")) {
                 if (mHasCopySupport) {
-                    auto *copy = w->findChild<QCheckBox *>(QStringLiteral("copy"));
+                    auto copy = w->findChild<QCheckBox *>(QStringLiteral("copy"));
                     copy->setChecked(true);
                 } else {
                     error += i18n("Action \"fileinto\" has \"copy\" argument but current server does not support it") + QLatin1Char('\n');
@@ -59,7 +59,7 @@ void SieveActionFileInto::setParamWidgetValue(QXmlStreamReader &element, QWidget
                 }
             } else if (tagValue == QLatin1String("create")) {
                 if (mHasMailBoxSupport) {
-                    auto *create = w->findChild<QCheckBox *>(QStringLiteral("create"));
+                    auto create = w->findChild<QCheckBox *>(QStringLiteral("create"));
                     create->setChecked(true);
                 } else {
                     serverDoesNotSupportFeatures(QStringLiteral("create"), error);
@@ -71,14 +71,14 @@ void SieveActionFileInto::setParamWidgetValue(QXmlStreamReader &element, QWidget
             }
         } else if (tagName == QLatin1String("str")) {
             const QString tagValue = element.readElementText();
-            auto *edit = w->findChild<KSieveUi::AbstractMoveImapFolderWidget *>(QStringLiteral("fileintolineedit"));
+            auto edit = w->findChild<KSieveUi::AbstractMoveImapFolderWidget *>(QStringLiteral("fileintolineedit"));
             edit->setText(AutoCreateScriptUtil::protectSlash(tagValue));
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             element.skipCurrentElement();
-            //implement in the future ?
+            // implement in the future ?
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << " SieveActionFileInto::setParamWidgetValue unknown tagName " << tagName;
@@ -88,18 +88,18 @@ void SieveActionFileInto::setParamWidgetValue(QXmlStreamReader &element, QWidget
 
 QWidget *SieveActionFileInto::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QHBoxLayout(w);
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout(w);
     lay->setContentsMargins({});
 
     if (mHasCopySupport) {
-        QCheckBox *copy = new QCheckBox(i18n("Keep a copy"));
+        auto copy = new QCheckBox(i18n("Keep a copy"));
         copy->setObjectName(QStringLiteral("copy"));
         lay->addWidget(copy);
         connect(copy, &QCheckBox::clicked, this, &SieveActionFileInto::valueChanged);
     }
     if (mHasMailBoxSupport) {
-        QCheckBox *create = new QCheckBox(i18n("Create folder"));
+        auto create = new QCheckBox(i18n("Create folder"));
         create->setObjectName(QStringLiteral("create"));
         connect(create, &QCheckBox::clicked, this, &SieveActionFileInto::valueChanged);
         lay->addWidget(create);
@@ -146,12 +146,14 @@ QString SieveActionFileInto::help() const
 {
     QString helpStr = i18n("The \"fileinto\" action delivers the message into the specified mailbox.");
     if (mHasMailBoxSupport) {
-        helpStr += QLatin1Char('\n') + i18n(
-            "If the optional \":create\" argument is specified, it instructs the Sieve interpreter to create the specified mailbox, if needed, before attempting to deliver the message into the specified mailbox.");
+        helpStr += QLatin1Char('\n')
+            + i18n("If the optional \":create\" argument is specified, it instructs the Sieve interpreter to create the specified mailbox, if needed, before "
+                   "attempting to deliver the message into the specified mailbox.");
     }
     if (mHasCopySupport) {
-        helpStr += QLatin1Char('\n') + i18n(
-            "If the optional \":copy\" keyword is specified, the tagged command does not cancel the implicit \"keep\". Instead, it merely files or redirects a copy in addition to whatever else is happening to the message.");
+        helpStr += QLatin1Char('\n')
+            + i18n("If the optional \":copy\" keyword is specified, the tagged command does not cancel the implicit \"keep\". Instead, it merely files or "
+                   "redirects a copy in addition to whatever else is happening to the message.");
     }
     return helpStr;
 }
