@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef REGEXPEDITORLINEEDIT_H
-#define REGEXPEDITORLINEEDIT_H
+#pragma once
 
 #include "ksieveui_private_export.h"
 #include <KSieveUi/AbstractRegexpEditorLineEdit>
@@ -27,8 +26,7 @@ public:
     void setPlaceholderText(const QString &str) override;
 
 private:
-    QLineEdit *mLineEdit = nullptr;
+    QLineEdit *const mLineEdit;
 };
 }
 
-#endif // REGEXPEDITORLINEEDIT_H
