@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVEEDITORLOADPROGRESSINDICATOR_H
-#define SIEVEEDITORLOADPROGRESSINDICATOR_H
+#pragma once
 
 #include <KPixmapSequence>
 #include <QObject>
@@ -30,8 +29,7 @@ private:
     void slotTimerDone();
     int mProgressCount = 0;
     KPixmapSequence mProgressPix;
-    QTimer *mProgressTimer = nullptr;
+    QTimer *const mProgressTimer;
 };
 }
 
-#endif // SIEVEEDITORLOADPROGRESSINDICATOR_H
