@@ -31,7 +31,11 @@ void SieveTemplateListWidget::setSieveCapabilities(const QStringList &capabiliti
     mCapabilities = capabilities;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 QMimeData *SieveTemplateListWidget::mimeData(const QList<QListWidgetItem *> items) const
+#else
+QMimeData *SieveTemplateListWidget::mimeData(const QList<QListWidgetItem *> &items) const
+#endif
 {
     if (items.isEmpty()) {
         return nullptr;
