@@ -28,7 +28,11 @@ public:
     void setSieveCapabilities(const QStringList &capabilities);
 
 protected:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QMimeData *mimeData(const QList<QListWidgetItem *> items) const override;
+#else
+    QMimeData *mimeData(const QList<QListWidgetItem *> &items) const override;
+#endif
 
 private:
     QStringList mCapabilities;
@@ -40,7 +44,7 @@ class SieveTemplateWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveTemplateWidget(const QString &title, QWidget *parent = nullptr);
-    ~SieveTemplateWidget();
+    ~SieveTemplateWidget() override;
 
     void setSieveCapabilities(const QStringList &capabilities);
 Q_SIGNALS:
