@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef VACATIONCHECKJOB_H
-#define VACATIONCHECKJOB_H
+#pragma once
 
 #include <QObject>
 #include <QStringList>
@@ -34,12 +33,12 @@ public:
     Q_REQUIRED_RESULT QString serverName() const;
 
 Q_SIGNALS:
-    void vacationScriptActive(VacationCheckJob *job, const QString &sscriptName, bool active);
+    void vacationScriptActive(KSieveUi::VacationCheckJob *job, const QString &sscriptName, bool active);
     void error(const QString &errorStr);
 
 private Q_SLOTS:
     void slotGetResult(KManageSieve::SieveJob *job, bool success, const QString &script, bool active);
-    void slotGotActiveScripts(ParseUserScriptJob *job);
+    void slotGotActiveScripts(KSieveUi::ParseUserScriptJob *job);
     void slotGotList(KManageSieve::SieveJob *job, bool success, const QStringList &availableScripts, const QString &activeScript);
     void emitError(const QString &errorMessage);
     void searchVacationScript();
@@ -62,4 +61,3 @@ private:
 };
 }
 
-#endif // VACATIONCHECKJOB_H
